@@ -192,7 +192,7 @@ class CGDB:
          """
         self._sites_manager.create_station(name, code, gpsLatitude, gpsLongitude, altitude, stationNetworkCode, stationGroupCode, remark)
 
-    def create_station_group(self, code, name, description):
+    def create_station_group(self, code, name=None, description=None):
         """Create station
 
          :type name: str
